[the-board] [ui] Only animate new things when window is visible



commit 495a0da4fa0e3be10d569bac7b23a6f8bb878eb6
Author: Lucas Rocha <lucasr gnome org>
Date:   Sat Nov 27 01:30:31 2010 +0000

    [ui] Only animate new things when window is visible

 src/js/ui/page.js |    8 +++++---
 1 files changed, 5 insertions(+), 3 deletions(-)
---
diff --git a/src/js/ui/page.js b/src/js/ui/page.js
index ddd74b0..73c78e7 100644
--- a/src/js/ui/page.js
+++ b/src/js/ui/page.js
@@ -410,9 +410,11 @@ Page.prototype = {
         if (addToModel) {
             this._model.addThing(state);
 
-            // animate only new things
-            this.setActiveThing(thing);
-            this._animateNewThing(thing);
+            // animate only new things if window is visible
+            if (this._context.gtkWindow.visible) {
+                this.setActiveThing(thing);
+                this._animateNewThing(thing);
+            }
         }
     },
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]